# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.13
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class CertSigningReqStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'certificates': 'list[X509Certificate]',
        'common_name': 'str',
        'dns_names': 'list[str]'
    }

    attribute_map = {
        'certificates': 'certificates',
        'common_name': 'common_name',
        'dns_names': 'dns_names'
    }

    def __init__(self, certificates=None, common_name=None, dns_names=None, local_vars_configuration=None):  # noqa: E501
        """CertSigningReqStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._certificates = None
        self._common_name = None
        self._dns_names = None
        self.discriminator = None

        if certificates is not None:
            self.certificates = certificates
        if common_name is not None:
            self.common_name = common_name
        if dns_names is not None:
            self.dns_names = dns_names

    @property
    def certificates(self):
        """Gets the certificates of this CertSigningReqStatus.  # noqa: E501

        The issued x509 certificates, formatted as PEM. This list is sorted by X509Certificate.not_before.   # noqa: E501

        :return: The certificates of this CertSigningReqStatus.  # noqa: E501
        :rtype: list[X509Certificate]
        """
        return self._certificates

    @certificates.setter
    def certificates(self, certificates):
        """Sets the certificates of this CertSigningReqStatus.

        The issued x509 certificates, formatted as PEM. This list is sorted by X509Certificate.not_before.   # noqa: E501

        :param certificates: The certificates of this CertSigningReqStatus.  # noqa: E501
        :type: list[X509Certificate]
        """

        self._certificates = certificates

    @property
    def common_name(self):
        """Gets the common_name of this CertSigningReqStatus.  # noqa: E501

        The certificate common name (CN)   # noqa: E501

        :return: The common_name of this CertSigningReqStatus.  # noqa: E501
        :rtype: str
        """
        return self._common_name

    @common_name.setter
    def common_name(self, common_name):
        """Sets the common_name of this CertSigningReqStatus.

        The certificate common name (CN)   # noqa: E501

        :param common_name: The common_name of this CertSigningReqStatus.  # noqa: E501
        :type: str
        """

        self._common_name = common_name

    @property
    def dns_names(self):
        """Gets the dns_names of this CertSigningReqStatus.  # noqa: E501

        The list of domains of which the CSR is requesting to be issued to.  # noqa: E501

        :return: The dns_names of this CertSigningReqStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._dns_names

    @dns_names.setter
    def dns_names(self, dns_names):
        """Sets the dns_names of this CertSigningReqStatus.

        The list of domains of which the CSR is requesting to be issued to.  # noqa: E501

        :param dns_names: The dns_names of this CertSigningReqStatus.  # noqa: E501
        :type: list[str]
        """

        self._dns_names = dns_names

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CertSigningReqStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CertSigningReqStatus):
            return True

        return self.to_dict() != other.to_dict()
